@@ -1,9 +1,8 @@
 //! Clients for Google Cloud Storage endpoints.
 
-use std::fmt;
-use tokio::sync::Mutex;
+use std::{fmt, sync};
 
-use crate::token::Token;
+use crate::token::TokenCache;
 
 mod bucket;
 mod bucket_access_control;
@@ -22,9 +21,8 @@ pub use object_access_control::ObjectAccessControlClient;
 /// The primary entrypoint to perform operations with Google Cloud Storage.
 pub struct Client {
     client: reqwest::Client,
-
     /// Static `Token` struct that caches
-    token_cache: Mutex<Token>,
+    token_cache: sync::Arc<dyn crate::TokenCache + Send>,
 }
 
 impl fmt::Debug for Client {
@@ -40,19 +38,32 @@ impl Default for Client {
     fn default() -> Self {
         Self {
             client: Default::default(),
-            token_cache: Mutex::new(Token::new(
-                "https://www.googleapis.com/auth/devstorage.full_control",
-            )),
+            token_cache: sync::Arc::new(crate::Token::default()),
         }
     }
 }
 
 impl Client {
-    /// Constructs a client
+    /// Constructs a client with the default token provider, where it attemps to obtain the
+    /// credentials from the following locations:
+    ///
+    /// 1. Checks for the environment variable `SERVICE_ACCOUNT`, and if it exists, reads the file
+    /// at the path specified there as a credentials json file.
+    /// 2. It attemps to do the same with the `GOOGLE_APPLICATION_CREDENTIALS` var.
+    /// 3. It reads the `SERVICE_ACCOUNT_JSON` environment variable directly as json and uses that
+    /// 4. It attemps to do the same with the `GOOGLE_APPLICATION_CREDENTIALS_JSON` var.
     pub fn new() -> Self {
         Default::default()
     }
 
+    /// Initializer with a provided refreshable token
+    pub fn with_cache(token: impl TokenCache + Send + 'static) -> Self {
+        Self {
+            client: Default::default(),
+            token_cache: sync::Arc::new(token),
+        }
+    }
+
     /// Operations on [`Bucket`](crate::bucket::Bucket)s.
     pub fn bucket(&self) -> BucketClient<'_> {
         BucketClient(self)
@@ -85,8 +96,7 @@ impl Client {
 
     async fn get_headers(&self) -> crate::Result<reqwest::header::HeaderMap> {
         let mut result = reqwest::header::HeaderMap::new();
-        let mut guard = self.token_cache.lock().await;
-        let token = guard.get(&self.client).await?;
+        let token = self.token_cache.get(&self.client).await?;
         result.insert(
             reqwest::header::AUTHORIZATION,
             format!("Bearer {}", token).parse().unwrap(),
