@@ -1,7 +1,7 @@
 use crate::{
     bucket::{IamPolicy, TestIamPermission},
-    object::percent_encode,
     error::GoogleResponse,
+    object::percent_encode,
     resources::common::ListResponse,
     Bucket, NewBucket,
 };
@@ -73,9 +73,20 @@ impl<'a> BucketClient<'a> {
     /// # }
     /// ```
     pub async fn list(&self) -> crate::Result<Vec<Bucket>> {
-        let url = format!("{}/b/", crate::BASE_URL);
+        let url = dbg!(format!("{}/b/", crate::BASE_URL));
         let project = &crate::SERVICE_ACCOUNT.project_id;
         let query = [("project", project)];
+        dbg!(
+            self.0
+                .client
+                .get(&url)
+                .headers(self.0.get_headers().await?)
+                .query(&query)
+                .send()
+                .await?
+                .text()
+                .await
+        )?;
         let result: GoogleResponse<ListResponse<Bucket>> = self
             .0
             .client
@@ -114,11 +125,7 @@ impl<'a> BucketClient<'a> {
     /// # }
     /// ```
     pub async fn read(&self, name: &str) -> crate::Result<Bucket> {
-        let url = format!(
-            "{}/b/{}",
-            crate::BASE_URL,
-            percent_encode(name),
-        );
+        let url = format!("{}/b/{}", crate::BASE_URL, percent_encode(name),);
         let result: GoogleResponse<Bucket> = self
             .0
             .client
@@ -163,11 +170,7 @@ impl<'a> BucketClient<'a> {
     /// # }
     /// ```
     pub async fn update(&self, bucket: &Bucket) -> crate::Result<Bucket> {
-        let url = format!(
-            "{}/b/{}",
-            crate::BASE_URL,
-            percent_encode(&bucket.name),
-        );
+        let url = format!("{}/b/{}", crate::BASE_URL, percent_encode(&bucket.name),);
         let result: GoogleResponse<Bucket> = self
             .0
             .client
@@ -342,7 +345,11 @@ impl<'a> BucketClient<'a> {
                 "tested permission must not be `storage.buckets.list` or `storage.buckets.create`",
             ));
         }
-        let url = format!("{}/b/{}/iam/testPermissions", crate::BASE_URL, percent_encode(&bucket.name));
+        let url = format!(
+            "{}/b/{}/iam/testPermissions",
+            crate::BASE_URL,
+            percent_encode(&bucket.name)
+        );
         let result: GoogleResponse<TestIamPermission> = self
             .0
             .client
