@@ -1,12 +1,11 @@
 use crate::{
     bucket_access_control::{BucketAccessControl, Entity, NewBucketAccessControl},
-    object::percent_encode,
     error::GoogleResponse,
+    object::percent_encode,
     resources::common::ListResponse,
 };
 
 /// Operations on [`BucketAccessControl`](BucketAccessControl)s.
-#[derive(Debug)]
 pub struct BucketAccessControlClient<'a>(pub(super) &'a super::Client);
 
 impl<'a> BucketAccessControlClient<'a> {
@@ -39,11 +38,7 @@ impl<'a> BucketAccessControlClient<'a> {
         bucket: &str,
         new_bucket_access_control: &NewBucketAccessControl,
     ) -> crate::Result<BucketAccessControl> {
-        let url = dbg!(format!(
-            "{}/b/{}/acl",
-            crate::BASE_URL,
-            percent_encode(bucket),
-        ));
+        let url = format!("{}/b/{}/acl", crate::BASE_URL, percent_encode(bucket));
         let result: GoogleResponse<BucketAccessControl> = self
             .0
             .client
@@ -114,7 +109,12 @@ impl<'a> BucketAccessControlClient<'a> {
     /// # }
     /// ```
     pub async fn read(&self, bucket: &str, entity: &Entity) -> crate::Result<BucketAccessControl> {
-        let url = format!("{}/b/{}/acl/{}", crate::BASE_URL, percent_encode(bucket), percent_encode(&entity.to_string()));
+        let url = format!(
+            "{}/b/{}/acl/{}",
+            crate::BASE_URL,
+            percent_encode(bucket),
+            percent_encode(&entity.to_string())
+        );
         let result: GoogleResponse<BucketAccessControl> = self
             .0
             .client
