@@ -71,7 +71,7 @@
 //! # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 //! let client = Client::default();
 //! let mut object = client.object().read("mybucket", "myfile").await?;
-//! object.name = "mybetterfile".to_string();
+//! object.content_type = Some("application/xml".to_string());
 //! client.object().update(&object).await?;
 //! # Ok(())
 //! # }
@@ -98,6 +98,7 @@ mod error;
 mod resources;
 mod token;
 
+use crate::resources::service_account::ServiceAccount;
 pub use crate::{
     client::Client,
     error::*,
@@ -106,8 +107,8 @@ pub use crate::{
         object::{ListRequest, Object},
         *,
     },
+    token::{Token, TokenCache},
 };
-use crate::{resources::service_account::ServiceAccount, token::Token};
 pub use download_options::DownloadOptions;
 use tokio::sync::Mutex;
 
